package cc_petitions.survey.web;

import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

import cc_petitions.survey.service.SurveyService;
import cc_petitions.survey.service.SurveyVO;
import egovframework.com.cmm.EgovMessageSource;
import egovframework.com.cmm.LoginVO;
import egovframework.rte.fdl.property.EgovPropertyService;
import egovframework.rte.ptl.mvc.tags.ui.pagination.PaginationInfo;

@Controller
@RequestMapping(value = "/site/survey")
public class surveyController{
	
	@Resource(name = "surveyService")
	private SurveyService surveyService;
	
	@Resource(name = "propertiesService")
	protected EgovPropertyService propertyService;
	
	@Resource(name = "egovMessageSource")
    protected EgovMessageSource egovMessageSource;

	//2018-07-18 윤영탁 설문조사 이용자 페이지 추가
	@RequestMapping(value="/surveyList.do")
	public String surveyList(HttpServletRequest request, ModelMap model, @ModelAttribute("searchVO") SurveyVO surveyVO) throws Exception{
		LoginVO user = (LoginVO) request.getSession().getAttribute("loginVO");
		
		PaginationInfo paginationInfo = new PaginationInfo();
		
		paginationInfo.setCurrentPageNo(surveyVO.getPageIndex());
		paginationInfo.setRecordCountPerPage(surveyVO.getPageUnit());
		paginationInfo.setPageSize(surveyVO.getPageSize());
		
		surveyVO.setFirstIndex(paginationInfo.getFirstRecordIndex());
		surveyVO.setLastIndex(paginationInfo.getLastRecordIndex());
		surveyVO.setRecordCountPerPage(paginationInfo.getRecordCountPerPage());
		surveyVO.setUse_flag("Y");
		
		Map<String, Object> map = surveyService.selectSurveyArticles(surveyVO);// 2011.09.07
		int totCnt = Integer.parseInt((String) map.get("resultCnt"));
		
		paginationInfo.setTotalRecordCount(totCnt);
		
		int pageCnt = paginationInfo.getTotalPageCount();
		
		model.addAttribute("resultList", map.get("resultList"));
		model.addAttribute("resultCnt", map.get("resultCnt"));
		model.addAttribute("paginationInfo", paginationInfo);
		model.addAttribute("pageCnt", pageCnt);

		model.addAttribute("userInfo", user);
		model.addAttribute("name", "survey");
		return "/site/survey/surveyList";
	}
	
	//2017-11-29 윤영탁 이용자페이지 설문 글보기
	@RequestMapping(value = "/surveyView.do")
	public String surveyView(HttpServletRequest request, @ModelAttribute("searchVO") SurveyVO surveyVO, ModelMap model) throws Exception {
		LoginVO user = (LoginVO) request.getSession().getAttribute("loginVO");
    	if (user == null) {
    		String returnUrl = "";
    		request.getSession().setAttribute("returnUrl", returnUrl);
    		
			return "redirect:/site/mypage/login.do";
		}else{
			SurveyVO survey = surveyService.getSurvey(surveyVO.getQue_id());
			request.setCharacterEncoding("UTF-8");
			
			SurveyVO userSurvey = new SurveyVO();
			userSurvey.setMberId(user.getId());
			userSurvey.setQue_id(surveyVO.getQue_id());
			
			if(survey.getLogin_flag().equals("Y")){
				if(survey.getDup_flag().equals("N")){
					int resultCount = surveyService.selectSurveyUser(userSurvey);
					
					if(resultCount > 0){
						String msg = "code01";
						model.addAttribute("msg", msg);
						return "redirect:/site/survey/surveyList.do";
					}
				}
			}

			List<SurveyVO> anQuestionResult = surveyService.selectAnQueList(survey);
			int anQuestionResultCnt = surveyService.selectAnQueListCnt(survey);

			//설문조사 답변 항목 가져오기
			List<SurveyVO> surveyQueItem = surveyService.selectQueItemList(surveyVO.getQue_id());
			
			//설문조사 참여인원 가져오기
			int applyCnt = surveyService.selectApplyCnt(userSurvey);

			model.addAttribute("queListCnt", anQuestionResultCnt);
			model.addAttribute("queList", anQuestionResult);
			model.addAttribute("surveyQueItem", surveyQueItem);
			model.addAttribute("que_id", surveyVO.getQue_id());
			model.addAttribute("survey", survey);
			model.addAttribute("applyCnt", applyCnt);
				
			model.addAttribute("name", "survey");
			return "/site/survey/surveyView";
		}
	}
		
		
	//2017-12-05 윤영탁 이용자페이지 설문 작성하기
	@RequestMapping(value = "/surveyWrite.do", method = RequestMethod.POST)
	public String surveyWrite(HttpServletRequest request, SurveyVO surveyVO, ModelMap model) throws Exception {
		LoginVO user = (LoginVO) request.getSession().getAttribute("loginVO");
    	if (user == null) {
    		String returnUrl = "";
    		request.getSession().setAttribute("returnUrl", returnUrl);
    		
			return "redirect:/site/mypage/login.do";
		}else{
			int queListCnt = Integer.parseInt(request.getParameter("queListCnt"));
			
			SurveyVO survey = surveyService.getSurvey(surveyVO.getQue_id());
			if(survey.getLogin_flag().equals("Y")){
				surveyVO.setMberId(user.getId());
				surveyVO.setMberNm(user.getName());
				surveyVO.setBirth(user.getBirthday());
				surveyVO.setGender(user.getGender());
				surveyVO.setQue_id(Integer.parseInt(request.getParameter("que_id")));
				surveyService.insertSurveyUser(surveyVO);
			}else{
				surveyVO.setMberId("");
				surveyVO.setMberNm("");
				surveyVO.setBirth("");
				surveyVO.setGender("");
				surveyVO.setQue_id(Integer.parseInt(request.getParameter("que_id")));
				surveyService.insertSurveyUser(surveyVO);
			}
			
			
			for (int i = 1; i <= queListCnt; i++) {//질문 갯수만큼 반복			
				if(request.getParameter("item_type"+i).equals("1")){//단일선택
					surveyVO.setAnque_id(Integer.parseInt(request.getParameter("anque_id"+i)));
					surveyVO.setItem_type(request.getParameter("item_type"+i));
					surveyVO.setSubject_answer("");
				
					String itemque_id = request.getParameter("itemque_id"+i);
					surveyVO.setItemque_id(Integer.parseInt(itemque_id));
					
					surveyService.insertSurveyResult(surveyVO);
					
				}else if(request.getParameter("item_type"+i).equals("2")){//다중선택
					surveyVO.setAnque_id(Integer.parseInt(request.getParameter("anque_id"+i)));
					surveyVO.setItem_type(request.getParameter("item_type"+i));
					surveyVO.setSubject_answer("");
					
					String[] itemque_id = request.getParameterValues("itemque_id"+i);
					
					for (int j = 0; j < itemque_id.length; j++) {
						surveyVO.setItemque_id(Integer.parseInt(itemque_id[j]));
						surveyService.insertSurveyResult(surveyVO);
					}
					
				}else if(request.getParameter("item_type"+i).equals("3")){//주관식
					surveyVO.setAnque_id(Integer.parseInt(request.getParameter("anque_id"+i)));
					surveyVO.setItem_type(request.getParameter("item_type"+i));
					surveyVO.setItemque_id(Integer.parseInt(request.getParameter("itemque_id"+i)));
					surveyVO.setSubject_answer(request.getParameter("subject_answer"+i));
					surveyService.insertSurveyResult(surveyVO);
					
				}else if(request.getParameter("item_type"+i).equals("4")){//단일선택(기타)
					surveyVO.setAnque_id(Integer.parseInt(request.getParameter("anque_id"+i)));
					surveyVO.setItem_type(request.getParameter("item_type"+i));
					surveyVO.setSubject_answer(request.getParameter("subject_answer"+i));
				
					String itemque_id = request.getParameter("itemque_id"+i);
					surveyVO.setItemque_id(Integer.parseInt(itemque_id));
					
					surveyService.insertSurveyResult(surveyVO);
				}
				
			}
			return "redirect:/site/survey/surveyList.do";
		}
	}
}

